#
# spec file for package tracker-miners
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define tracker_basever 3.6

Name:           tracker-miners
Version:        3.6.2
Release:        4.2
Summary:        Various miners for Tracker
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Projects/Tracker
Source0:        https://download.gnome.org/sources/tracker-miners/%{tracker_basever}/%{name}-%{version}.tar.xz

### NOTE: Keep please SLE-only patches at bottom (starting on 1000).
# PATCH-FIX-SLE tracker-miners-drop-syscalls-in-seccomp.patch bsc#1192567 qkzhu@suse.com -- Revert some syscalls in seccomp since Leap and SLE do not have them
Patch1000:      tracker-miners-drop-syscalls-in-seccomp.patch

BuildRequires:  asciidoc
BuildRequires:  giflib-devel
BuildRequires:  intltool >= 0.40.0
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  meson >= 0.51.0
BuildRequires:  pkgconfig
BuildRequires:  tracker-data-files
BuildRequires:  vala
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(enca) >= 1.9
BuildRequires:  pkgconfig(exempi-2.0) >= 2.1.0
BuildRequires:  pkgconfig(gexiv2)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.62.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.62.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.62.0
BuildRequires:  pkgconfig(gstreamer-1.0) >= 0.10.31
BuildRequires:  pkgconfig(gstreamer-audio-1.0) >= 0.10.31
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= 0.10.31
BuildRequires:  pkgconfig(gstreamer-tag-1.0) >= 0.10.31
BuildRequires:  pkgconfig(icu-i18n) >= 4.8.1.1
BuildRequires:  pkgconfig(icu-uc) >= 4.8.1.1
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcue) >= 2.0.0
BuildRequires:  pkgconfig(libexif) >= 0.6
BuildRequires:  pkgconfig(libgsf-1) >= 1.14.24
BuildRequires:  pkgconfig(libgxps)
BuildRequires:  pkgconfig(libiptcdata)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(libosinfo-1.0) >= 0.2.9
BuildRequires:  pkgconfig(libseccomp) >= 2.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6
BuildRequires:  pkgconfig(poppler-glib) >= 0.16.0
BuildRequires:  pkgconfig(totem-plparser)
BuildRequires:  pkgconfig(tracker-sparql-3.0) >= 3.5.0
BuildRequires:  pkgconfig(upower-glib) >= 0.9.0
# The schema files moved from libtracker-common to tracker-miners
Conflicts:      libtracker-common-1_0 < 1.99
# Make sure tracker is being updated to 1.99 too
Conflicts:      tracker < 1.99
Obsoletes:      tracker-miner-rss <= 2.2.2
Requires:       tracker >= %{tracker_basever}
%requires_ge    tracker-data-files

%description
Tracker is a desktop-neutral object database, tag/metadata database,
search tool and indexer.

These are the sources for the various miners (e.g. files, rss)

%package -n tracker-miner-files
Summary:        Tracker miner to index files and applications
Group:          System/GUI/GNOME
Requires:       %{name} >= %{version}

%description -n tracker-miner-files
Tracker is a desktop-neutral object database, tag/metadata database,
search tool and indexer.

This package contains a miner to index files and applications.

%lang_package

%prep
%setup -q

# SLE and Leap only patches start at 1000
%if 0%{?sle_version}
%patch -P 1000 -p1
%endif

%build
%meson \
	-Dsystemd_user_services_dir=%{_userunitdir} \
	-Dfunctional_tests=false \
	-Dminer_rss=false \
	%{nil}
%meson_build

%install
%meson_install
%find_lang tracker3-miners

%post
%systemd_user_post tracker-extract-3.service tracker-writeback-3.service tracker-miner-fs-3.service tracker-miner-fs-control-3.service

%preun
%systemd_user_preun tracker-extract-3.service tracker-writeback-3.service tracker-miner-fs-3.service tracker-miner-fs-control-3.service

%files
%license COPYING
%doc README.md
%{_datadir}/dbus-1/interfaces/org.freedesktop.Tracker3.Miner.xml
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Miner.Extract.service
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Writeback.service
%{_datadir}/glib-2.0/schemas/org.freedesktop.Tracker3.Extract.gschema.xml
%{_datadir}/glib-2.0/schemas/org.freedesktop.Tracker3.FTS.gschema.xml
%{_datadir}/tracker3-miners/
%dir %{_libdir}/tracker-miners-3.0
%{_libdir}/tracker-miners-3.0/extract-modules/
%{_libdir}/tracker-miners-3.0/libtracker-extract.so
%{_libdir}/tracker-miners-3.0/writeback-modules/
%{_libexecdir}/tracker3/
%{_libexecdir}/tracker-extract-3
%{_libexecdir}/tracker-writeback-3
%{_mandir}/man1/tracker3-daemon.1%{?ext_man}
%{_mandir}/man1/tracker3-extract.1%{?ext_man}
%{_mandir}/man1/tracker3-index.1%{?ext_man}
%{_mandir}/man1/tracker3-info.1%{?ext_man}
%{_mandir}/man1/tracker3-reset.1%{?ext_man}
%{_mandir}/man1/tracker3-search.1%{?ext_man}
%{_mandir}/man1/tracker3-status.1%{?ext_man}
%{_mandir}/man1/tracker3-tag.1%{?ext_man}
%{_mandir}/man1/tracker-writeback-3.1%{?ext_man}
%{_userunitdir}/tracker-extract-3.service
%{_userunitdir}/tracker-writeback-3.service

%files -n tracker-miner-files
%{_datadir}/dbus-1/interfaces/org.freedesktop.Tracker3.Miner.Files.Index.xml
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Miner.Files.Control.service
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Miner.Files.service
%{_datadir}/glib-2.0/schemas/org.freedesktop.Tracker3.Miner.Files.gschema.xml
%{_datadir}/glib-2.0/schemas/org.freedesktop.TrackerMiners3.enums.xml
%{_libexecdir}/tracker-miner-fs-3
%{_libexecdir}/tracker-miner-fs-control-3
%{_mandir}/man1/tracker-miner-fs-3.1%{?ext_man}
%{_sysconfdir}/xdg/autostart/tracker-miner-fs-3.desktop
%{_userunitdir}/tracker-miner-fs-3.service
%{_userunitdir}/tracker-miner-fs-control-3.service

%files lang -f tracker3-miners.lang

%changelog
* Thu Dec 28 2023 Yifan Jiang <yfjiang@suse.com>
- Rebase tracker-miners-drop-syscalls-in-seccomp.patch
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Wed Nov  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.6.2:
  + Improvements to the seccomp jail, and fixes for spurious SIGSYS
    positives.
  + Use GDateTime to handle dates.
  + Updated translations.
* Fri Sep 29 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.6.1:
  + Avoid the special thread in tracker-extract-3, and extend the
    seccomp jail to the full process.
  + Updated translations.
  + Drop upstream merged: tracker-miners-CVE-2023-5557.patch
- Add a tracker_basever define, and set it to 3.6. We have a hard
  Requires on what tracker version is needed and it is currently
  set at the same or newer version, change this to tracker_basever
  (tracker-miners have never been at a higher patch version
  before).
* Mon Sep 18 2023 Alynx Zhou <alynx.zhou@suse.com>
- Add tracker-miners-CVE-2023-5557.patch: A bug in libcue could
  lead to possible sandbox escape in tracker-extract, this fixes it
  by adding seccomp rules and applying it to the whole process
  (bsc#1216199, glgo#GNOME/tracker-miners!480, CVE-2023-5557).
- Refresh tracker-miners-drop-syscalls-in-seccomp.patch: The patch
  context is changed by tracker-miners-CVE-2023-5557.patch.
* Sat Sep 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.6.0:
  + Fix possible race condition between directory crawling and
    monitoring.
  + Improved "tracker3 info" output.
  + Cleanups to tracker-miner-fs-3 code.
  + Updated translations.
* Wed Sep  6 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 3.6.rc:
  + Throttle extractor process on battery conditions.
  + Handle deletion of directories no longer configured as indexed.
  + Lower footprint crawling very large directories.
  + Hint tracker-extract-3 file access with posix_fadvise.
  + Raise file descriptor limit in tracker-miner-fs-3.
  + Updated translations.
* Wed Aug 16 2023 Rahul Jain <rahul.jain@suse.com>
- Update
  + Fix the tracker miner spec file to build for SLE_15
  + Rebase patch: tracker-miners-drop-syscalls-in-seccomp.patch
* Fri Aug 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.6.beta:
  + Stop indexing applications.
  + Improve performance of reindexes induced by indexer changes.
  + More performance improvements in hot startup cases.
  + Fix potential infinite loops with unexpected Fanotify events.
  + Build fixes.
  + Updated translations.
* Fri Jul  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.6.alpha:
  + Greatly improve performance and memory usage during
    post-startup checks on an already indexed filesystem.
  + Build system fixes.
  + Updated translations.
* Thu May 18 2023 Luciano Santos <luc14n0@opensuse.org>
- Drop %%systemd_user_postun_with_restart macro from the %%postun
  directive. It's been deprecated and emptied (expands to nil) on
  both Tumbleweed and Leap already.
* Sat May 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.5.2:
  + Fix a number of potential crashers.
  + Fix possibly stuck extractor process.
  + Restore performance lost in 3.5.1 of extractor query to get
    unextracted items.
  + Plug memory leak.
* Tue Apr 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.5.1:
  + The tracker-extract-3 service moved all SPARQL queries and
    updates to a GResource. Consistently uses
    TrackerSparqlStatement/TrackerResource for updates.
  + Fixes in uniquely identifying files in BTRFS subvolumes.
  + Ensure deletion of files lingering in content graphs.
  + Ensure correct nie:dataSource after moving files between
    indexed folders.
  + Optimize mass removal of deleted files found during
    initialization.
  + Documentation improvements for the miner services.
  + Do not let systemd spuriously start the tracker-extract-3
    service.
  + Test suite fixes.
* Sun Mar 26 2023 Enrico Belleri <idesmi@protonmail.com>
- Add 'tracker' to runtime dependencies (boo#1209737)
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.5.0:
  + Test suite fixes.
  + Added membarrier syscall to seccomp.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.5.0.rc:
  + Fix deletion of not yet extracted files.
  + Fix some memory leaks.
  + Updated translations.
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.5.0.beta:
  + The filesystem miner moved all SPARQL queries and updates to a
    GResource. Consistently uses
    TrackerSparqlStatement/TrackerResource for updates.
  + The "tracker3 tag" has been fixed, and functional tests added
    to avoid regressions.
  + The functional tests have been refurbished and modernized.
  + Internal code refactors.
  + The extractor test suite has been extended.
* Fri Feb 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.5.0.alpha:
  + Fix GSource leak in tracker-extract-3.
  + Disable 'fluidsynthmidi' GStreamer module.
  + Delegate tracker-miner-fs D-Bus SPARQL endpoint to a separate
    thread.
* Thu Jan 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.4.3:
  + Fix possible warnings in tracker-miner-fs-3
  + Fixes to handle BTRFS subvolumes
  + Reset nie:isStoredAs/nie:interpretedAs on updated folders
  + Drop 'fluidsynthmidi' GStreamer module
  + Fix GSource leak
  + Updated translations.
* Mon Dec  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.4.2:
  + Fix advised flatpak command in sandboxing documentation.
  + Fix intermittent build break.
  + Updated translations.
* Wed Oct 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.4.1:
  + Warning fixes to gstreamer extractor.
  + Silence EXDEV warnings on FANotify monitor failures, likely in
    some systems.
  + New handled syscalls in seccomp: set_mempolicy, get_mempolicy,
    epoll_create1.
  + Improve performance of lookups of related CUE files for
    gstreamer media.
  + Fix memory leaks.
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.4.0:
  + Updated translations.
* Mon Sep  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.4.0.rc:
  + Fixes to libav/ffmpeg extractor.
  + Remove text/plain files from ignored-files, there are more
    specific setting to control indexed text content.
  + Fix build on MacOS.
  + Fix compiler/build warnings.
  + Updated translations.
* Wed Aug 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.4.0.beta:
  + Add --list and --delete options to RSS miner.
  + Text extraction fixes on ODS and ODG file formats.
  + Improve logging of filesystem miner elapsed time information.
  + Improve performance of filesystem move operations.
  + Do not show duplicate results in "tracker3 search" CLI tool.
  + Updated translations.
- Drop 401.patch: Fixed upstream.
* Mon Aug  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add 401.patch: Specify graphs in "tracker3 search" queries;
  resolves tracker search listing files multiple times
  (boo#1200403 glgo#GNOME/tracker-miners#229).
* Sun Jul 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.4.0.alpha:
  + Fix fallback from fanotify to inotify.
  + Improvements to "tracker3 status" CLI.
  + Check field type on IPTC data embedded in TIFFs.
  + Avoid non-existent ontology in libav extractor.
  + Fix some file updates being missed through fanotify.
  + Fix possible tracker-miner-fs-3 crashes on shutdown.
  + Updated translations.
* Wed Jun  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.3.1:
  + Properly fallback to inotify monitors on fanotify failures.
  + Fixes to handling of files being atomically replaced.
  + Fixes to handling of IPTC data embedded in TIFFs.
  + Improvements to "tracker3 status" output and redirection
    handling.
* Fri Apr  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Pass -Dsystemd_user_services_dir=%%{_userunitdir} to meson: we
  either need pkgconfig(systemd) (which we so far just received
  indirectly by some dependencies) or pass the location to install
  userunitdirs to meson. As the variable is known already, we opted
  for this version, which is 'cheaper' on the build deps.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.3.0:
  + Initialize stable URN cache prior to extractor modules in
    tracker-extract-3.
* Mon Mar  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.3.0.rc:
  + Ignore subtrack titles for videos.
  + OpenBSD improvements to `tracker3 reset/daemon` CLI commands.
  + Improved test infrastructure around removable device support.
  + Fixed FANotify monitor to handle separate FAN_DELETE[_SELF]
    events.
  + Fixed generation of man pages with newer asciidoc.
* Mon Mar  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.3.0.beta:
  + Changed to skip mountpoints found during recursive indexing.
    Mountpoints must be explicitly configured as indexed folders
    now.
  + Fixed FANotify monitor to safely fallback to inotify in the
    cases not currently covered by FANotify (e.g. btrfs
    subvolumes).
  + Improved the stable URN scheme so it is guaranteed to be
    stable.
  + Removed deprecated API usage in libav extractor.
  + Fix --show-files in "tracker3 tag".
  + Fix possible crashes with Clang.
- Drop patches fixed upstream:
  + tracker-miners-allow-rseq.patch
  + tracker-miners-allow-mbind.patch
* Mon Mar  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.3.0.alpha:
  + Use FANotify for file monitoring if available.
  + Use a more stable URN scheme for file content.
  + Add indexing roots to content specific graphs for availability
    info.
  + Truly disable nvcodec in gstreamer extractor.
  + Use the configured domain prefix in miner symlinks.
  + Add seccomp rules for recently used syscalls.
  + Performance improvements to tracker-miner-fs-3.
  + Plug memory leaks in tracker-miner-fs-3.
  + Updated translations.
* Mon Mar  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.2.2:
  + Backport seccomp rules for rseq and mbind syscalls.
  + Updated translations.
- Drop patches fixed upstream:
  + tracker-miners-allow-mbind.patch
  + tracker-miners-allow-rseq.patch
* Fri Feb 25 2022 Michael Gorse <mgorse@suse.com>
- Add tracker-miners-allow-rseq.patch and
  tracker-miners-allow-mbind.patch: allow system calls used by
  gstreamer (boo#1196205 glgo#GNOME/tracker-miners#210).
* Thu Dec  2 2021 QK ZHU <qkzhu@suse.com>
- Add tracker-miners-drop-syscalls-in-seccomp.patch:
  Revert upstream commit 595560c, 30b24e9 and 550ea1b since Leap
  15.4 and SLE 15-SP4 do not have them (bsc#1192567).
* Tue Nov  9 2021 Alynx Zhou <alynx.zhou@suse.com>
- Drop 0001-Revert-tracker-Use-faster-query-in-tracker3-info.patch:
  Upstream fix landed in tracker instead of tracker-miners.
  (bsc#1191207, glgo#GNOME/tracker#337)
* Fri Nov  5 2021 Alynx Zhou <alynx.zhou@suse.com>
- Add 0001-Revert-tracker-Use-faster-query-in-tracker3-info.patch:
  Revert the commit to avoid wrong no metadata info. (bsc#1191207)
* Sat Oct 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.2.1:
  + Fix files moving between hidden and non-hidden
  + Update nfo:fileName on content specific graphs too when moved
  + Update nfo:fileLastModified in content specific graphs
  + Add nfo:fileSize to the basic set of file info on the graph
  + Fix tracker-miner-fs-3 crash when finding internal SPARQL
    errors
  + Handle symlinks to directories as indexed folders better
  + Fix tracker-writeback support for musicbrainz release tags and
    artist
  + Fix duplicate entries on files created and instantly modified
  + Fix unintended double extraction with disc-generic extractor
  + Fixes for coverity warnings
  + Updated translations.
- Add missing systemd user service handling in post/preun/postun
* Wed Sep 22 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.2.0:
  + Highlighted changes since 3.1:
  - File creation time is now part of the stored metadata
  - Show additional information in "tracker3 info"
  + Updated translations.
* Wed Sep 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.2.0.rc:
  + Updated translations.
* Tue Sep 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.2.0.beta:
  + Save file creation time.
  + Coverity fixes.
  + Fix chaining up of errors after porting to TrackerBatch.
  + Fixes for test flakiness.
  + Avoid falling back to year 0 in extractors.
  + Linking fixes on misc executables.
  + CI improvements.
  + Updated translations.
* Tue Sep 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.2.0.alpha.1:
  + Brown paper bag release.
- Changes from version 3.2.0.alpha:
  + Remove default limit in "tracker3 search" command.
  + Show additional information in "tracker3 info".
  + Fix "tracker index" crash on broken XDG directory setups.
  + Updated translations.
* Tue Sep 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.1.3:
  + Fix issue with missing rpath in control daemon.
  + Add further newly used syscalls to seccomp
  + Updated translations.
- Drop tracker-miner-control-rpath,patch: Fixed upstream.
* Mon Jun 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add tracker-miner-control-rpath,patch: Fix runpath in
  trcker-miner-control-fs.
* Sat Jun 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.1.2:
  + Fixes to libav extractor.
  + Allow 64bit time syscalls for 32bit systems in seccomp sandbox.
  + Manpage fixes.
  + Build fixes.
  + Updated translations.
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.1.1:
  + Block gstreamer nvcodec decoders.
  + Fall back if no modification date is found.
  + Handle new poppler enum value.
  + Be more robust with broken EXIF GPS metadata.
  + Test suite improvements.
  + Updated translations.
* Tue Mar 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.1.0:
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.1.0.rc:
  + Dispatch monitor events on a private thread.
  + Fix After= usage in systemd service files.
  + Fix compiler warnings.
* Tue Feb 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.1.0.beta:
  + Fix tracker-miner-fs-control-3 stall on shutdown.
  + Improve ellipsizing in CLI tools.
  + Update list of game-related mimetypes.
  + Add disc-generic extractor guessing data for CUE files,
    supported so far:
  - Playstation images
  - Turbografx images
  + Updated translations.
* Sat Jan 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.1.0.alpha:
  + Fix "tracker3 search --folders".
  + Allow "tracker3 search" to look for filenames.
  + Improve "tracker3 info" to show file eligibility if not
    indexed.
  + Many performance improvements to tracker-miner-fs-3.
  + Fix systemd unit files to depend on gnome-session.
  + Improve time_t interpretation for negative timestamps.
* Mon Jan 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.0.4:
  + Improve time_t interpretation for negative timestamps.
  + Fix "tracker3 search --folders".
  + Fix crasher after tracker-miner-fs SPARQL failures.
  + CI fixes.
* Thu Dec 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.0.3:
  + Allow newstatat/statat64 syscalls
  + Brown paper bag release
- Changes from version 3.0.2:
  + Fix sched test under non glibc platforms
  + Refcount fixes
  + Avoid the fluiddec gstreamer plugin
  + Ensure to avoid non-native files in tracker-extract-3
  + CI fixes
  + Updated translations.
* Sat Oct 24 2020 Marcus Rueckert <mrueckert@suse.de>
- require the newly split out tracker-data-files
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.0.1:
  + Fix moving files and directories leaving stale data.
  + Better handling of faulty SPARQL from tracker-extract.
  + Fix chromaprint tag extraction in gstreamer extractor causing
    bad SPARQL.
  + Reference Discourse instead of the mailing list.
  + Forward tracker-extract state.
  + Use specific Meson options to enable debug flags.
  + Fix stop words location when building with system Tracker.
  + Small libtracker-miners-common clean ups.
  + Check for malloc_trim function being available.
  + Fixes for Coverity warnings.
  + Compiler warning fixes.
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.0.0:
  + Updated translations.
* Wed Sep  9 2020 dimstar@opensuse.org
- Update to version 2.99.5:
  + Always create content resource for text files.
  + Calculate per extract module timings in
    TRACKER_DEBUG=statistics.
  + Add mtime information to graph-specific nfo:FileDataObjects.
  + Add option to set the D-Bus domain at build time.
  + Ensure memory is released on inactivity or memory pressure.
  + Updated translations.
* Mon Sep  7 2020 dimstar@opensuse.org
- Update to version 2.99.4:
  + CLI modernization:
  - Integration with pager.
  - "tracker3 index" makes persistent configuration changes.
  - "tracker3 info --eligible $file" tells whether a file would
    be indexed, or why not.
  - "tracker3 reset" resets better.
  - "tracker3 daemon" terminates processes better.
  - "tracker3 search" fixes.
  - Erase ^C after monitoring subcommands.
  - "tracker3 status" shows reports about files that failed
    indexing/metadata extraction.
  + Fixes to removable mount handling.
  + Use curly quotes consistently in setting description strings.
  + Better use of asserts in tests.
  + Update seccomp rules to work with modern glib.
- Changes from version 2.99.3:
  + Support musicbrainz tags in gstreamer module.
  + Support acoustid tag writeback.
  + Handle nmm:artist and nmm:performer.
  + DBus API changes.
  + Fixes for race conditions.
  + Performance improvements.
  + Extractor watchdog fixes with domain ontologies.
  + CLI improvements.
  + Test fixes.
  + Use background slice.
  + Add base tests for CLI.
  + Better debugging traces.
  + Fix extraction of files with dummy extractors.
- Changes from version 2.99.2:
  + Constraint the indexed text formats to txt/markdown, a new
    setting allows handling other formats.
  + Add rules for game ROM formats.
  + Support automatic re-extraction on extractor changes.
  + Vorbis and flac specific extractors were dropped, those are
    handled by gstreamer.
  + Improve usage of nie:dataSource, now there is one per indexed
    folder, no longer used by tracker-extract.
  + Fixes to album/disc IRI generation.
  + Writeback handling is rewritten, now performed via an explicit
    DBus call.
  + Add support for musicbrainz and acoustid fingerprint.
  + Set a deadline of 30 seconds for extraction tasks.
  + Many build, leak and performance fixes.
- Changes from version 2.99.1:
  + Highlighted updates compared to 2.x:
  - tracker-miner-fs/tracker-extract and tracker-miner-rss data
    are split into 2 endpoints:
    . org.freedesktop.Tracker3.Miner.Files
    . org.freedesktop.Tracker3.Miner.RSS
  - tracker-miner-fs data is split into different graphs:
    . tracker:FileSystem
    . tracker:Audio
    . tracker:Video
    . tracker:Documents
    . tracker:Software
  - Full split between file and content elements. 1:1, 1:N, M:1
    and M:N are allowed combinations of those, they relate to
    each other through the nie:isStoredAs and nie:interpretedAs
    properties.
  - Parallel installable to tracker-miners 2.x
  - Better, more tests
  - Reincorporated libtracker-miner and libtracker-control code.
    These are no longer for public consumption
  + Updated translations.
- Drop tracker-miners-bsc1165635-crawl-timestamp.patch: no longer
  applicable.
- Add asciidoc and pkgconfig(libnm) BuildRequires: new
  dependencies.
- Replace pkgconfig(tracker-sparql-2.0) BuildRequires with
  pkgconfig(tracker-sparql-3.0): Follow the switch to Tracker 3.
- Drop no longer needed BuildRequires (due to reorganisation):
  pkgconfig(flac), pkgconfig)vorbisfile),
  pkgconfig(tracker-miner-2.0)
* Tue Aug 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.3.4:
  + Block image/ktx files in 90-gstreamer-image-generic.rule.
  + Set a deadline of 30 seconds for extraction tasks.
  + Remove generic gstreamer-based image extraction codepath.
  + Several fixes to libav-based extractor.
  + Replace sensitive words.
  + Get the systemd user unit dir from pkg-config.
  + Updated translations.
* Tue Mar 10 2020 mgorse@suse.com
- Update to version 2.3.3:
  + The secure sandbox for tracker-extract now permits
    clock_nanosleep() calls, fixing crashes on some systems.
  + Miners now set nice/scheduler priorities in a way that placates
    glib. The sched_setscheduler syscall is as a side effect also
    allowed by the tracker-extract sandbox.
  + Updated translations.
- Drop tracker-miners-set-cpu-io-nice.patch and
  tracker-miners-allow-settatr.patch: fixed upstream.
- Add tracker-miners-bsc1165635-crawl-timestamp.patch: properly set
  crawl timestamp (bsc#1165635 glgo#GNOME/tracker-miners!159).
* Sat Feb 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream bug fix patches:
  + tracker-miners-set-cpu-io-nice.patch
  + tracker-miners-allow-settatr.patch
* Tue Feb 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.3.2:
  + Blocked parsing of image/x-dds image files, which were
    previously being passed to GStreamer and triggering system
    lockups for some people.
  + Fixed incorrect MIME type for .raw images, which were
    previously being passed to GStreamer and triggering system
    lockups for some people.
  + Improved how the MP3 extractor calculates durations of variable
    bitrate MP3s, which fixes incorrect durations being shown in
    GNOME Music.
  + Fixed a bug in the GStreamer writeback module.
  + Fix race condition that might leave tracker-miner-fs paused
    after a writeback operation.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Oct 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.3.1:
  + Improved .odt extraction, fixing issues with hyphenated words.
  + OpenBSD: Fixed build.
  + functional-tests: Fixed a cause of intermittent failures,
    removed some unused data files.
  + Minor compiler warning and build system fixes.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 2.3.0:
  + No changes since 2.2.99.1.
* Thu Sep  5 2019 mgorse@suse.com
- Update to version 2.2.99.1:
  + The ~/Downloads folder is now indexed non-recursively by
    default. This reduces the risk of Tracker unnecessarily
    crawling large directories of source code or video game data.
  - If users are storing data such as music or photos in
    subfolders of the Downloads folder, they will need to move it
    to an appropriate place (~/Music, ~/Pictures, etc.) so that
    it is still indexed.
  + Dispose TrackerResource objects before unref.
  + Fixes in Musicbrainz metadata extraction.
  + Translations: ca, eu.
* Mon Aug 26 2019 yfjiang@suse.com
- Update to version 2.2.99.0:
  + Support for reading Musicbrainz metadata from audio files.
  + Tracker Writeback now uses GStreamer to write metadata to audio
    files, instead of depending on taglib directly.
  + Directories will now be ignored if they contain a file named
    `.nomedia`. A file named `.trackerignore` has the same effect,
    but the `.nomedia` file brings us in line with Android.
  + Removed obsolete 'max-media-art-width' setting.
- libtracker-miners-common is built as a static library and only
  used in build time. So remove it in the %%install section.
- Add a new BuildRequires pkgconfig(gstreamer-audio-1.0).
- Drop an unused BuildRequires pkgconfig(taglib_c).
* Tue Jun 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(libgrss) BuildRequires and subpackage
  tracker-miner-rss: libfrss is dropped upstream. Following this,
  add tracker-miner-rss Obsoletes to main tracker-miners package.
* Fri May  3 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.2.2:
  + Multiple leak fixes.
  + Functional tests now use python3.
  + Fix text extractor handling of non-existent files.
  + Fix indexing of tracks in FLAC files.
  + Added new tests for file formats.
  + Updated translations.
* Thu Mar  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.2.1:
  + Whitelist syscall fadvise64_64.
  + Many fixes to functional tests.
  + Fix failed functional tests being reported as successful.
  + Updated translations.
* Mon Feb 25 2019 bjorn.lie@gmail.com
- Update to version 2.2.0:
  + Disable guarantee_metadata by default. It was the case on
    autotools.
  + Stop merging translations to schema files.
  + Test suite improvements.
  + Meson build improvements.
  + The functionality of tracker-miner-apps has been adopted by
    tracker-miner-fs/tracker-extract.
  + All usage of deprecated TrackerSparqlBuilder is gone.
  + Fixes to desktop file indexing.
  + Multiple build and compile warning fixes.
  + Many test improvements and cleanups.
  + The functionality of tracker-miner-apps has been adopted by
    tracker-miner-fs/tracker-extract.
  + Updated tracker-miner-fs and tracker-miner-rss to use
    TrackerResource.
  + Support for building through autotools has been removed.
  + Plugged several leaks.
  + Other many build and code cleanups and fixes.
  + Updated translations.
- Switch to meson build system, remove all conditionals for meson
  and remove all traces of autotools support.
- Drop tracker-miners-private.patch: finally fixed upstream
  (probably by accident, but well).
- Add pkgconfig(gexiv2), pkgconfig(libavcodec),
  pkgconfig(libavformat) and pkgconfig(libavutil) BuildRequires:
  New dependencies, all optional except gexiv2.
* Sun Feb 24 2019 bjorn.lie@gmail.com
- Update to version 2.1.6:
  + Multiple meson build fixes.
  + Test fixes.
  + Updated translations.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 2.1.5:
  + Fix several leaks.
  + Ensure utf8ness in
    tracker_guarantee_resource_title_from_file().
  + Updated translations.
* Tue Sep  4 2018 bjorn.lie@gmail.com
- Update to version 2.1.4:
  + Updated translations.
- Changes from version 2.1.3:
  + Unbreak watch on domain ontology owner. Fixes miners spuriously
    exiting.
* Sat Sep  1 2018 bjorn.lie@gmail.com
- Update to version 2.1.2:
  + Allow use of domain rules outside prefix.
  + Add core-as-subproject as explicit meson option.
  + Ensure utf8ness in TrackerResource helpers.
  + Fix multiple cardinality issues in different
    extractors/properties.
  + Other minor SPARQL correctness fixes.
  + Updated translations.
* Thu Aug 16 2018 bjorn.lie@gmail.com
- Update to version 2.1.1:
  + tracker-miner-fs: Ignore mercurial repositories.
  + build: Fix build with -Werror=format-security.
  + tracker-extract:
  - Ensure metadata strings are UTF-8 in JPEG/PNG extractors.
  - Do not add named destinations to PDF TOCs.
  - Ignore XMP image metadata on PDFs.
  - Fix ISO 8601 date string generation on gstreamer extractor.
  + Updated translations.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 2.1.0:
  + tests: Many updates and fixes to functional tests.
  + tracker-extract: Better infrastructure for tests, based on
    JSON-LD.
  + tracker-miner-fs: Restart tracker extract from the right
    domain.
  + tracker-extract: Persistently avoid files that trigger
    recoverable errors, to avoid log spamming on restarts.
  + Updated translations.
* Tue Jun 26 2018 luc14n0@linuxmail.org
- Update to version 2.0.5:
  + tracker-extract: Made daemon able to shutdown on inactivity,
    lifetime will be managed by tracker-miner-fs.
  + tracker-stract: Fixes in generated SPARQL for geolocation data.
  + Updated translations.
- Replace libjpeg-devel BuildRequires with pkgconfig(libjpeg): now
  configure looks for the pkgconfig module instead.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb  7 2018 bjorn.lie@gmail.com
- Update to version 2.0.4:
  + build: Allow building tracker repo as a meson subproject.
  + libtracker-common: Rename to libtracker-miners-common.
  + libtracker-miners-common: Whitelist arm_fadvise64_64, getegid
    and getegid32 syscalls.
  + tracker-extract:
  - Add GExiv2-based extractor module for RAW files.
  - Blacklist gstreamer modules via plugin instead of via
    feature.
  - Blacklist video4linux2 gstreamer plugin.
  - Use enumerations for EXIF values.
  - Fix image pixel density conversions.
  + tracker-miner-fs: Avoid setting rdf:types on empty files.
  + meson: dependency check fixes.
  + Updated translations.
- Drop tracker-miners-nb-translations.patch: Fixed upstream.
* Sat Jan  6 2018 zaitor@opensuse.org
- Add tracker-miners-nb-translations.patch: Update Norwegian Bokmål
  translations.
* Thu Nov 16 2017 luc14n0@linuxmail.org
- Update to version 2.0.3:
  + meson: Multiple cleanups and fixes.
  + tracker-extract: Do not overwrite nie:dataSource.
- Update Url to https://wiki.gnome.org/Projects/Tracker: current
  Tracker's web page.
* Fri Oct  6 2017 zaitor@opensuse.org
- Update to version 2.0.2:
  + tracker-miner-fs: Fix initialization when there's a startup
    timeout.
  + tracker-extract: Don't store 0-length strings on MSOffice
    metadata.
  + Updated translations.
* Thu Oct  5 2017 dimstar@opensuse.org
- Update to version 2.0.1:
  + tracker-miner-apps: Ignore broken .desktop file symlinks.
  + tracker-miner-fs: Ignore non-native mounts.
  + tracker-extract: Fix insertion of white balance values in
    images.
  + Compile warnings and Coverity issue fixes.
  + Fix srcdir!=builddir builds.
- Drop tracker-miners-tracker-extract-fixes.patch: fixed upstream.
* Sat Sep 23 2017 zaitor@opensuse.org
- Add tracker-miners-tracker-extract-fixes.patch: Fix various bugs
  in tracker-extract (bgo#785853, bgo#787774).
* Tue Sep 12 2017 dimstar@opensuse.org
- Update to version 2.0.0:
  + Tracker shall from now on use semantic versioning.
  + autotools/meson cleanups.
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Add releavant conflicts to ease upgrades from old tracker
  versions: tracker and libtracker-common-1_0: Various files moved
  from to tracker-miners.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 1.99.3:
  + Add more assertions to testcases (CIDs 162185, 162186,
    162188–162191).
  + Protect further the MP3 parser against out-of-bounds reads
    (CID #162187).
  + Fixed typos, and other code and build improvements.
  + Updated translations.
* Tue Aug 15 2017 dimstar@opensuse.org
- Initial package, version 1.99.2:
  + Tracker-miners has been split out from tracker.
